<template>
  <LoadingLayout :loading="state.loading">
    <AppContainer>
      <ProTableQueryFilterBar @on-reset="reset">
        <template #query>
          <QueryFilterItem>
            <FieldDatePicker
              v-model="extraParamState.creationDate"
              type="daterange"
              range-separator="~"
              start-placeholder="起始时间"
              end-placeholder="结束时间"
              clearable
              @change="getList()"
              tooltipContent="操作时间"
            ></FieldDatePicker>
          </QueryFilterItem>
        </template>
      </ProTableQueryFilterBar>
      <ProTableV2 v-bind="proTableProps" :columns="columns" :operationBtns="operationBtns">
      </ProTableV2>
    </AppContainer>
  </LoadingLayout>
</template>

<script setup lang="ts">
import {
  ProTableQueryFilterBar,
  ProTableV2,
  LoadingLayout,
  AppContainer,
  QueryFilterItem,
  useTable,
  FieldDatePicker,
  defineOperationBtns,
  defineColumns,
} from '@bole-core/components';
import * as insuranceOrderServices from '@/services/api/InsuranceOrder';
import { OrderInputType, downloadFileByUrl } from '@bole-core/core';
import { format, setOSSLink } from '@/utils';
import { ModelValueType } from 'element-plus';
import { InsurancePolicyStatusEnumText, InsurancePolicyStatusEnum } from '@/constants';

defineOptions({
  name: 'FileManage',
});

const columns = defineColumns([
  {
    id: '1',
    enCode: 'q',
    name: '标题',
  },
  {
    id: '2',
    enCode: 'q',
    name: '时间',
  },
  {
    id: '3',
    enCode: 'q',
    name: '操作',
  },
  {
    id: '4',
    enCode: 'q',
    name: '状态',
  },
]);

const operationBtns = defineOperationBtns([
  {
    data: {
      enCode: 'downloadFileBtn',
      name: '下载文件',
    },
    emits: {
      onClick: (role) => handleDownloadFile(role),
    },
  },
  {
    data: {
      enCode: 'downloadOriginalFileBtn',
      name: '下载原文件',
    },
    emits: {
      onClick: (role) => handleDownloadOriginalFile(role),
    },
  },
  {
    data: {
      enCode: 'downloadErrorDataBtn',
      name: '下载错误数据',
    },
    emits: {
      onClick: (role) => handleDownloadErrorData(role),
    },
  },
]);

const BaseState = {
  loading: true,
};

const state = reactive({ ...BaseState });

onMounted(async () => {
  await getList();
  state.loading = false;
});

const {
  getDataSource: getList,
  proTableProps,
  paginationState,
  extraParamState,
  reset,
} = useTable(
  async ({ pageIndex, pageSize }, extraParamState) => {
    try {
      let params: API.GetInsurancePageInput = {
        pageModel: {
          rows: pageSize,
          page: pageIndex,
          orderInput: extraParamState.orderInput,
        },
        importStartDateTime: format(extraParamState.creationDate?.[0] ?? '', 'YYYY-MM-DD 00:00:00'),
        importEndDateTime: format(extraParamState.creationDate?.[1] ?? '', 'YYYY-MM-DD 23:59:59'),
        insurancePeriod: extraParamState.insurancePeriod,
        status: extraParamState.status,
      };
      let res = await insuranceOrderServices.getInsurancePage(params, {
        showLoading: !state.loading,
      });
      return res;
    } catch (error) {}
  },
  {
    defaultExtraParams: {
      orderInput: [{ property: 'id', order: OrderInputType.Desc }],
      creationDate: [] as unknown as ModelValueType,
      status: '' as any as InsurancePolicyStatusEnum,
      insurancePeriod: '',
    },
    columnsRenderProps: {
      status: { type: 'enum', valueEnum: InsurancePolicyStatusEnumText },
      effectEndTime: { type: 'date', format: 'YYYY-MM-DD' },
    },
  }
);

function handleDownloadFile(row: API.GetInsurancePageOutput) {
  downloadFileByUrl(setOSSLink(row.insureBillUrl));
}
function handleDownloadOriginalFile(row: API.GetInsurancePageOutput) {
  downloadFileByUrl(setOSSLink(row.insureBillUrl));
}
function handleDownloadErrorData(row: API.GetInsurancePageOutput) {
  downloadFileByUrl(setOSSLink(row.insureBillUrl));
}
</script>
